<?php

namespace Litecms\Buslisting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Buslisting\Models\Buslisting;

class BuslistingPolicy
{

    /**
     * Determine if the given user can view the buslisting.
     *
     * @param UserPolicy $user
     * @param Buslisting $buslisting
     *
     * @return bool
     */
    public function view(UserPolicy $user, Buslisting $buslisting)
    {
        if ($user->canDo('buslisting.buslisting.view') && $user->isAdmin()) {
            return true;
        }

        return $buslisting->user_id == user_id() && $buslisting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a buslisting.
     *
     * @param UserPolicy $user
     * @param Buslisting $buslisting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buslisting.buslisting.create');
    }

    /**
     * Determine if the given user can update the given buslisting.
     *
     * @param UserPolicy $user
     * @param Buslisting $buslisting
     *
     * @return bool
     */
    public function update(UserPolicy $user, Buslisting $buslisting)
    {
        if ($user->canDo('buslisting.buslisting.edit') && $user->isAdmin()) {
            return true;
        }

        return $buslisting->user_id == user_id() && $buslisting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given buslisting.
     *
     * @param UserPolicy $user
     * @param Buslisting $buslisting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Buslisting $buslisting)
    {
        return $buslisting->user_id == user_id() && $buslisting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given buslisting.
     *
     * @param UserPolicy $user
     * @param Buslisting $buslisting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Buslisting $buslisting)
    {
        if ($user->canDo('buslisting.buslisting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given buslisting.
     *
     * @param UserPolicy $user
     * @param Buslisting $buslisting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Buslisting $buslisting)
    {
        if ($user->canDo('buslisting.buslisting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
